@@ -21,54 +21,56 @@
 #ifndef FX_SET_H
 #define FX_SET_H
 
-enum
-{
+enum{
 	COMBO_NAME_COL = 0 ,
 	COMBO_ID_COL ,
 	COMBO_COLS_NUM
 };
-typedef enum
-{
+typedef enum{
 	SEND_MODE_ENTER ,
 	SEND_MODE_CTRL_ENTER
 } SendModeType;
 
-typedef enum
-{
+typedef enum{
 	AUTO_POPUP_DISABLE ,
 	AUTO_POPUP_ENABLE
 } AutoPopupType;
 
-typedef enum
-{
+typedef enum{
 	AUTO_REPLY_DISABLE ,
 	AUTO_REPLY_ENABLE
 } AutoReplyType;
 
-typedef enum
-{
+typedef enum{
 	CLOSE_DESTROY_MODE ,
 	CLOSE_ICON_MODE 
 } CloseType;
 
-typedef enum
-{
+typedef enum{
 	MUTE_DISABLE ,
 	MUTE_ENABLE
 } MuteType;
 
-typedef enum
-{
+typedef enum{
 	PAGE_PERSONAL ,
 	PAGE_SYSTEM
 } NotebookPageType;
 
-typedef enum
-{
+typedef enum{
 	ICON_CAN ,
 	ICON_CANNOT 
 } IconType;
 
+typedef enum {
+	AUTO_AWAY_ENABLE,
+	AUTO_AWAY_DISABLE
+} AutoAway;
+
+typedef enum {
+	ONLINE_NOTIFY_ENABLE,
+	ONLINE_NOTIFY_DISABLE
+} OnlineNotify;
+
 extern FxSet* fx_set_new(FxMain* fxmain);
 
 extern void fx_set_initialize(FxSet* fxset);
