@@ -134,7 +134,6 @@ void fetion_user_list_save(Config* config , struct userlist* ul)
 {	
 	char path[256];
 	char sql[1024];
-	char password[1024];
 	sqlite3 *db;
 	char *errMsg = NULL;
 	struct userlist *pos;
@@ -154,13 +153,10 @@ void fetion_user_list_save(Config* config , struct userlist* ul)
 		return;
 	}
 
-
 	foreach_userlist(ul, pos){
-		sprintf(password, "%s", pos->password);
-		escape_sql(password);
 		sprintf(sql, "insert into userlist values"
 					"('%s','%s',%d,%d,'%s','%s')",
-					pos->no, password,
+					pos->no, pos->password,
 					pos->laststate, pos->islastuser,
 				   	pos->userid, pos->sid);
 		if(sqlite3_exec(db, sql, NULL, NULL, &errMsg)){
@@ -247,11 +243,6 @@ create_ul_table:
 		}
 	}
 
-	if(nrows == 0 || ncols == 0){
-		sqlite3_close(db);
-		return res;
-	}
-
 	debug_info("Loading user list store in local data file");
 	for(i = 0; i < nrows; i ++){
 		start = ncols + i * ncols;
@@ -261,7 +252,6 @@ create_ul_table:
 					sqlres[start + 5],
 				   	atoi(sqlres[start + 2]),
 					atoi(sqlres[start + 3]));
-		unescape_sql(pos->password);
 		fetion_user_list_append(res , pos);
 	}
 	sqlite3_close(db);
@@ -916,11 +906,10 @@ int fetion_user_list_remove(Config *config, const char *no)
 
 void escape_sql(char *in)
 {
-	while(*in){if(*in == '\'') *in = (char)255; in ++;}
+	while((*in)&&((*in)=='\'' ? (*in++)=(char)255 : in++));
 }
-void unescape_sql(char *inn)
+void unescape_sql(char *in)
 {
-	char *in = inn;
-	while(*in){if(*in == (char)255) *in = '\''; in ++;}
+	while((*in)&&((*in)==(char)255 ? (*in++)='\'' : in++));
 }
 
