@@ -199,20 +199,22 @@ void fetion_sip_add_header(FetionSip* sip , SipHeader* header)
 
 char* fetion_sip_to_string(FetionSip* sip , const char* body)
 {
-	char *res , *head , buf[1024] , type[128];
+	char *res , *head , buf[40] , type[5];
 	SipHeader *pos , *tmp;
 	int len = 0;
 
 	pos = sip->header;
-	while(pos){
+	while(pos != NULL)
+	{
 		len += (strlen(pos->value) + strlen(pos->name) + 5);
 		pos = pos->next;
 	}
 	len += (body == NULL ? 100 : strlen(body) + 100 );
 	res = (char*)malloc(len + 1);
 	memset(res , 0 , len + 1);
-	memset(type, 0 , sizeof(type));
-	switch(sip->type){
+	bzero(type , sizeof(type));
+	switch(sip->type)
+	{
 		case SIP_REGISTER     : strcpy(type , "R");
 			break;
 		case SIP_SUBSCRIPTION :	strcpy(type , "SUB");
@@ -232,25 +234,23 @@ char* fetion_sip_to_string(FetionSip* sip , const char* body)
 		default:
 			break;
 	};
-
 	if(strlen(type) == 0)
 		return NULL;
-
-	sprintf(buf, "%s fetion.com.cn SIP-C/4.0\r\n"
-			"F: %s\r\n"
-			"I: %d\r\n"
-			"Q: 2 %s\r\n",
-			type,
-			sip->from,
-			sip->callid,
-			type);
-
+	sprintf(buf , "%s fetion.com.cn SIP-C/4.0\r\n" , type);
+	strcpy(res , buf);
+	sprintf(buf , "F: %s\r\n" , sip->from);
+	strcat(res , buf);
+	sprintf(buf , "I: %d\r\n" , sip->callid);
+	strcat(res , buf);
+	sprintf(buf , "Q: 2 %s\r\n" , type);
 	strcat(res , buf);
 
 	pos = sip->header;
-	while(pos){
+	while(pos != NULL)
+	{
 		len = strlen(pos->value) + strlen(pos->name) + 5;
 		head = (char*)malloc(len);
+		memset(head , 0 , len);
 		sprintf(head , "%s: %s\r\n" , pos->name , pos->value);
 		strcat(res , head);
 		tmp = pos;
@@ -259,11 +259,15 @@ char* fetion_sip_to_string(FetionSip* sip , const char* body)
 		free(tmp->value);
 		free(tmp);
 	}
-	if(body){
+	if(body != NULL)
+	{
+		bzero(buf , sizeof(buf));
 		sprintf(buf , "L: %d\r\n\r\n" , strlen(body));
 		strcat(res , buf);
 		strcat(res , body);
-	}else{
+	}
+	else
+	{
 		strcat(res , "\r\n");
 	}
 	callid ++;
@@ -306,10 +310,10 @@ char* fetion_sip_get_pgid_by_sipuri(const char *pgsipuri)
 
 int fetion_sip_get_attr(const char* sip , const char* name , char* result)
 {
-	char m_name[16];
+	char m_name[5];
 	char* pos;
 	int n;
-
+	bzero(m_name , sizeof(m_name));
 	sprintf(m_name , "%s: " , name);
 	if(strstr(sip , m_name) == NULL)
 		return -1;
@@ -377,7 +381,7 @@ char* fetion_sip_get_response(FetionSip* sip)
 {
 	char *res;
 	unsigned int len , n , c , c1;
-	char buf[4096];
+	char buf[2048];
 
 	memset(buf , 0 , sizeof(buf));
 
@@ -388,16 +392,15 @@ char* fetion_sip_get_response(FetionSip* sip)
 
 	len = fetion_sip_get_length(buf);
 
-	while(strstr(buf , "\r\n\r\n") == NULL && c < sizeof(buf))
-		c += tcp_connection_recv(sip->tcp, buf + c, sizeof(buf) - c - 1);
-	
+	if(strstr(buf , "\r\n\r\n") == NULL)
+		return NULL;
 
 	n = strlen(buf) - strlen(strstr(buf , "\r\n\r\n") + 4);
 	len += n;
 	res = (char*)malloc(len + 1);
+	memset(res , 0 , len + 1);
 	if(res == NULL)
 		return NULL;
-	memset(res , 0 , len + 1);
 	strcpy(res , buf);
 	if(c < len)
 	   	for(;;){
@@ -1214,10 +1217,10 @@ void fetion_sip_get_auth_attr(const char* auth , char** ipaddress , int* port ,
 	char* pos = strstr(auth , "address=\"") + 9;
 	int n = strlen(pos) - strlen(strstr(pos , ":"));
 	char port_str[6] = { 0 };
-	*credential = (char*)malloc(256);
-	memset(*credential , 0 , 256);
-	*ipaddress = (char*)malloc(256);
-	memset(*ipaddress , 0 , 256);
+	*credential = (char*)malloc(48);
+	memset(*credential , 0 , 48);
+	*ipaddress = (char*)malloc(18);
+	memset(*ipaddress , 0 , 18);
 	strncpy(*ipaddress , pos , n);
 	pos = strstr(pos , ":") + 1;
 	n = strlen(pos) - strlen(strstr(pos , ";"));
