@@ -24,8 +24,6 @@ FxAddbuddy* fx_addbuddy_new(FxMain* fxmain)
 {
 	FxAddbuddy* fxaddbuddy = (FxAddbuddy*)malloc(sizeof(FxAddbuddy));
 
-	DEBUG_FOOTPRINT();
-
 	memset(fxaddbuddy , 0 , sizeof(FxAddbuddy));
 	fxaddbuddy->fxmain = fxmain;
 	fxaddbuddy->phraselist = fetion_config_get_phrase(fxmain->user->config);
@@ -40,8 +38,6 @@ void fx_addbuddy_initialize(FxAddbuddy* fxaddbuddy)
 	GtkWidget *group_entry , *name_hbox , *name_alignment;
 	GtkTreeModel* model;
 
-	DEBUG_FOOTPRINT();
-
 	fxaddbuddy->dialog = gtk_dialog_new();
 	icon = gdk_pixbuf_new_from_file(SKIN_DIR"add.png" , NULL);
 	gtk_window_set_icon(GTK_WINDOW(fxaddbuddy->dialog) , icon);
@@ -136,8 +132,6 @@ GtkTreeModel* fx_addbuddy_create_group_model(FxAddbuddy* fxaddbuddy)
 	char* groupname;
 	int groupid;
 
-	DEBUG_FOOTPRINT();
-
 	store = gtk_tree_store_new(GROUP_COL_NUMS , G_TYPE_STRING , G_TYPE_INT);
 	gtk_tree_model_get_iter_root(model , &iter);
 	do
@@ -161,8 +155,6 @@ void fx_addbuddy_bind(FxAddbuddy* fxaddbuddy)
 	Phrase *phrase;
 	User *user = fxaddbuddy->fxmain->user;
 
-	DEBUG_FOOTPRINT();
-
 
 	foreach_list(fxaddbuddy->phraselist , pos){
 		phrase = (Phrase*)(pos->data);
@@ -193,8 +185,6 @@ void fx_addbuddy_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 	char code[24];
 	User* user = fxadd->fxmain->user;
 
-	DEBUG_FOOTPRINT();
-
 	config = user->config;
 
 	if(fxadd->notype == FETION_NO)
@@ -225,15 +215,19 @@ void fx_addbuddy_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 	gtk_tree_model_get(model , &iter , GROUP_ID_COL , &buddylist , -1);
 	localname = gtk_entry_get_text(GTK_ENTRY(fxadd->name_entry));
 addbuddy:
-	contact = fetion_contact_add_buddy(user , no , fxadd->notype , buddylist , localname , desc , fxadd->phraseid , &ret);
+	contact = fetion_contact_add_buddy(user, no, fxadd->notype, buddylist, localname, desc, fxadd->phraseid, &ret);
+
 	switch(ret)
 	{
 		case BUDDY_USER_EXIST :
-			fx_util_popup_warning(fxadd->fxmain , _("The contact you want to add has already been in your contact list, please don't add him(her) repeatedly!"));
-			gtk_dialog_response(GTK_DIALOG(fxadd->dialog) , GTK_RESPONSE_OK);
+			fx_util_popup_warning(fxadd->fxmain,
+					_("The contact you want to add has already been in your contact list, please don't add him(her) repeatedly!"));
+			gtk_dialog_response(GTK_DIALOG(fxadd->dialog),
+					GTK_RESPONSE_OK);
 			return;
 		case BUDDY_SAME_USER_DAILY_LIMIT :
-			fx_util_popup_warning(fxadd->fxmain , _("You have reached the daily limit of adding buddies, please retry later"));
+			fx_util_popup_warning(fxadd->fxmain,
+					_("You have reached the daily limit of adding buddies, please retry later"));
 			gtk_dialog_response(GTK_DIALOG(fxadd->dialog) , GTK_RESPONSE_OK);
 			return;
 		case BUDDY_BAD_REQUEST :
@@ -297,13 +291,12 @@ addbuddy:
 
 		}
 	}
+
 	gtk_dialog_response(GTK_DIALOG(fxadd->dialog) , GTK_RESPONSE_OK);
 }
 
 void fx_addbuddy_on_cancel_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 {
-	DEBUG_FOOTPRINT();
-
 	gtk_dialog_response(GTK_DIALOG(data) , GTK_RESPONSE_CANCEL);
 }
 void fx_addbuddy_on_phrase_change(GtkWidget* widget , gpointer data)
@@ -313,8 +306,6 @@ void fx_addbuddy_on_phrase_change(GtkWidget* widget , gpointer data)
 	FxList *pos;
 	Phrase *phrase;
 
-	DEBUG_FOOTPRINT();
-
 	if(!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
 		return;
 	label = gtk_button_get_label(GTK_BUTTON(widget));
@@ -331,8 +322,6 @@ void fx_addbuddy_no_type_change(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxAddbuddy* fxaddbuddy = (FxAddbuddy*)data;
 
-	DEBUG_FOOTPRINT();
-
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxaddbuddy->fetion_button)))
 	{
 		fxaddbuddy->notype = FETION_NO;
