@@ -272,7 +272,7 @@ login:
 	   	user->loginStatus == 404){
 		debug_info("password ERROR!!!");
 		fx_login_show_err(fxlogin,
-			_("Login failed. \nIncorrect cell phone number or password"));
+			_("Login failed. Incorrect cell phone number or password"));
 		goto failed;
 	}
 	
@@ -534,8 +534,8 @@ auth:
 	gdk_threads_leave();
 
 	/* start sending keep alive request periodically */
-	g_timeout_add_seconds(70 , (GSourceFunc)fx_main_register_func , user);
-	g_timeout_add_seconds(5 , (GSourceFunc)fx_main_check_func , fxmain);
+	g_timeout_add_seconds(60 , (GSourceFunc)fx_main_register_func , user);
+	g_timeout_add_seconds(3 , (GSourceFunc)fx_main_check_func , fxmain);
 
 	g_thread_exit(0);
 failed:
